@@ -16,7 +16,7 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Type, Union, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import EndpointStateType, JobRunStateType, VirtualClusterStateType
 from .paginator import (
@@ -25,22 +25,22 @@ from .paginator import (
     ListVirtualClustersPaginator,
 )
 from .type_defs import (
-    CancelJobRunResponseResponseTypeDef,
+    CancelJobRunResponseTypeDef,
     ConfigurationOverridesTypeDef,
     ContainerProviderTypeDef,
-    CreateManagedEndpointResponseResponseTypeDef,
-    CreateVirtualClusterResponseResponseTypeDef,
-    DeleteManagedEndpointResponseResponseTypeDef,
-    DeleteVirtualClusterResponseResponseTypeDef,
-    DescribeJobRunResponseResponseTypeDef,
-    DescribeManagedEndpointResponseResponseTypeDef,
-    DescribeVirtualClusterResponseResponseTypeDef,
+    CreateManagedEndpointResponseTypeDef,
+    CreateVirtualClusterResponseTypeDef,
+    DeleteManagedEndpointResponseTypeDef,
+    DeleteVirtualClusterResponseTypeDef,
+    DescribeJobRunResponseTypeDef,
+    DescribeManagedEndpointResponseTypeDef,
+    DescribeVirtualClusterResponseTypeDef,
     JobDriverTypeDef,
-    ListJobRunsResponseResponseTypeDef,
-    ListManagedEndpointsResponseResponseTypeDef,
-    ListTagsForResourceResponseResponseTypeDef,
-    ListVirtualClustersResponseResponseTypeDef,
-    StartJobRunResponseResponseTypeDef,
+    ListJobRunsResponseTypeDef,
+    ListManagedEndpointsResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
+    ListVirtualClustersResponseTypeDef,
+    StartJobRunResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -67,30 +67,33 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class EMRContainersClient:
+class EMRContainersClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        EMRContainersClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#can_paginate)
         """
 
-    def cancel_job_run(
-        self, *, id: str, virtualClusterId: str
-    ) -> CancelJobRunResponseResponseTypeDef:
+    def cancel_job_run(self, *, id: str, virtualClusterId: str) -> CancelJobRunResponseTypeDef:
         """
         Cancels a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#cancel_job_run)
         """
 
@@ -106,11 +109,11 @@ class EMRContainersClient:
         clientToken: str,
         configurationOverrides: "ConfigurationOverridesTypeDef" = None,
         tags: Dict[str, str] = None
-    ) -> CreateManagedEndpointResponseResponseTypeDef:
+    ) -> CreateManagedEndpointResponseTypeDef:
         """
         Creates a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#create_managed_endpoint)
         """
 
@@ -121,57 +124,55 @@ class EMRContainersClient:
         containerProvider: "ContainerProviderTypeDef",
         clientToken: str,
         tags: Dict[str, str] = None
-    ) -> CreateVirtualClusterResponseResponseTypeDef:
+    ) -> CreateVirtualClusterResponseTypeDef:
         """
         Creates a virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#create_virtual_cluster)
         """
 
     def delete_managed_endpoint(
         self, *, id: str, virtualClusterId: str
-    ) -> DeleteManagedEndpointResponseResponseTypeDef:
+    ) -> DeleteManagedEndpointResponseTypeDef:
         """
         Deletes a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#delete_managed_endpoint)
         """
 
-    def delete_virtual_cluster(self, *, id: str) -> DeleteVirtualClusterResponseResponseTypeDef:
+    def delete_virtual_cluster(self, *, id: str) -> DeleteVirtualClusterResponseTypeDef:
         """
         Deletes a virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#delete_virtual_cluster)
         """
 
-    def describe_job_run(
-        self, *, id: str, virtualClusterId: str
-    ) -> DescribeJobRunResponseResponseTypeDef:
+    def describe_job_run(self, *, id: str, virtualClusterId: str) -> DescribeJobRunResponseTypeDef:
         """
         Displays detailed information about a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_job_run)
         """
 
     def describe_managed_endpoint(
         self, *, id: str, virtualClusterId: str
-    ) -> DescribeManagedEndpointResponseResponseTypeDef:
+    ) -> DescribeManagedEndpointResponseTypeDef:
         """
         Displays detailed information about a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_managed_endpoint)
         """
 
-    def describe_virtual_cluster(self, *, id: str) -> DescribeVirtualClusterResponseResponseTypeDef:
+    def describe_virtual_cluster(self, *, id: str) -> DescribeVirtualClusterResponseTypeDef:
         """
         Displays detailed information about a specified virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_virtual_cluster)
         """
 
@@ -185,7 +186,7 @@ class EMRContainersClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#generate_presigned_url)
         """
 
@@ -199,11 +200,11 @@ class EMRContainersClient:
         states: List[JobRunStateType] = None,
         maxResults: int = None,
         nextToken: str = None
-    ) -> ListJobRunsResponseResponseTypeDef:
+    ) -> ListJobRunsResponseTypeDef:
         """
         Lists job runs based on a set of parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_job_runs)
         """
 
@@ -217,21 +218,19 @@ class EMRContainersClient:
         states: List[EndpointStateType] = None,
         maxResults: int = None,
         nextToken: str = None
-    ) -> ListManagedEndpointsResponseResponseTypeDef:
+    ) -> ListManagedEndpointsResponseTypeDef:
         """
         Lists managed endpoints based on a set of parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_managed_endpoints)
         """
 
-    def list_tags_for_resource(
-        self, *, resourceArn: str
-    ) -> ListTagsForResourceResponseResponseTypeDef:
+    def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Lists the tags assigned to the resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_tags_for_resource)
         """
 
@@ -245,11 +244,11 @@ class EMRContainersClient:
         states: List[VirtualClusterStateType] = None,
         maxResults: int = None,
         nextToken: str = None
-    ) -> ListVirtualClustersResponseResponseTypeDef:
+    ) -> ListVirtualClustersResponseTypeDef:
         """
         Lists information about the specified virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_virtual_clusters)
         """
 
@@ -264,11 +263,11 @@ class EMRContainersClient:
         name: str = None,
         configurationOverrides: "ConfigurationOverridesTypeDef" = None,
         tags: Dict[str, str] = None
-    ) -> StartJobRunResponseResponseTypeDef:
+    ) -> StartJobRunResponseTypeDef:
         """
         Starts a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#start_job_run)
         """
 
@@ -276,7 +275,7 @@ class EMRContainersClient:
         """
         Assigns tags to resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#tag_resource)
         """
 
@@ -284,14 +283,14 @@ class EMRContainersClient:
         """
         Removes tags from resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#untag_resource)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listjobrunspaginator)
         """
 
@@ -300,7 +299,7 @@ class EMRContainersClient:
         self, operation_name: Literal["list_managed_endpoints"]
     ) -> ListManagedEndpointsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listmanagedendpointspaginator)
         """
 
@@ -309,6 +308,6 @@ class EMRContainersClient:
         self, operation_name: Literal["list_virtual_clusters"]
     ) -> ListVirtualClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listvirtualclusterspaginator)
         """
